==> seahorse-3.0.1-x86_64-1gsb.txz: install/doinst.sh <==
( cd usr/share/gnome/help/seahorse/vi/figures ; rm -rf seahorse-window.png )
( cd usr/share/gnome/help/seahorse/vi/figures ; ln -sf ../../C/figures/seahorse-window.png seahorse-window.png )
( cd usr/share/gnome/help/seahorse/sl/figures ; rm -rf seahorse-window.png )
( cd usr/share/gnome/help/seahorse/sl/figures ; ln -sf ../../C/figures/seahorse-window.png seahorse-window.png )
( cd usr/share/gnome/help/seahorse/oc/figures ; rm -rf seahorse-window.png )
( cd usr/share/gnome/help/seahorse/oc/figures ; ln -sf ../../C/figures/seahorse-window.png seahorse-window.png )
( cd usr/share/gnome/help/seahorse/ru/figures ; rm -rf seahorse-window.png )
( cd usr/share/gnome/help/seahorse/ru/figures ; ln -sf ../../C/figures/seahorse-window.png seahorse-window.png )
( cd usr/share/gnome/help/seahorse/zh_CN/figures ; rm -rf seahorse-window.png )
( cd usr/share/gnome/help/seahorse/zh_CN/figures ; ln -sf ../../C/figures/seahorse-window.png seahorse-window.png )
( cd usr/share/gnome/help/seahorse/en_GB/figures ; rm -rf seahorse-window.png )
( cd usr/share/gnome/help/seahorse/en_GB/figures ; ln -sf ../../C/figures/seahorse-window.png seahorse-window.png )
( cd usr/lib64 ; rm -rf libcryptui.so.0 )
( cd usr/lib64 ; ln -sf libcryptui.so.0.0.0 libcryptui.so.0 )
( cd usr/lib64 ; rm -rf libcryptui.so )
( cd usr/lib64 ; ln -sf libcryptui.so.0.0.0 libcryptui.so )

if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"    usr/bin/gconftool-2 --makefile-install-rule    etc/gconf/schemas/seahorse.schemas >/dev/null 2>&1
fi
# update rarian
if [ -x usr/bin/rarian-sk-update ]; then
  usr/bin/rarian-sk-update 1> /dev/null 2> /dev/null
fi

# update desktop entries
if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

# update icon cache
if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
	rm -f usr/share/icons/hicolor/icon-theme.cache
fi
usr/bin/gtk-update-icon-cache -f -q usr/share/icons/hicolor

==> seahorse-3.2.2-x86_64-1gsb.txz: install/doinst.sh <==
( cd usr/share/gnome/help/seahorse/vi/figures ; rm -rf seahorse-window.png )
( cd usr/share/gnome/help/seahorse/vi/figures ; ln -sf ../../C/figures/seahorse-window.png seahorse-window.png )
( cd usr/share/gnome/help/seahorse/ko/figures ; rm -rf seahorse-window.png )
( cd usr/share/gnome/help/seahorse/ko/figures ; ln -sf ../../C/figures/seahorse-window.png seahorse-window.png )
( cd usr/share/gnome/help/seahorse/ru/figures ; rm -rf seahorse-window.png )
( cd usr/share/gnome/help/seahorse/ru/figures ; ln -sf ../../C/figures/seahorse-window.png seahorse-window.png )
( cd usr/share/gnome/help/seahorse/gl/figures ; rm -rf seahorse-window.png )
( cd usr/share/gnome/help/seahorse/gl/figures ; ln -sf ../../C/figures/seahorse-window.png seahorse-window.png )
( cd usr/share/gnome/help/seahorse/zh_CN/figures ; rm -rf seahorse-window.png )
( cd usr/share/gnome/help/seahorse/zh_CN/figures ; ln -sf ../../C/figures/seahorse-window.png seahorse-window.png )
( cd usr/share/gnome/help/seahorse/sl/figures ; rm -rf seahorse-window.png )
( cd usr/share/gnome/help/seahorse/sl/figures ; ln -sf ../../C/figures/seahorse-window.png seahorse-window.png )
( cd usr/share/gnome/help/seahorse/en_GB/figures ; rm -rf seahorse-window.png )
( cd usr/share/gnome/help/seahorse/en_GB/figures ; ln -sf ../../C/figures/seahorse-window.png seahorse-window.png )
( cd usr/share/gnome/help/seahorse/oc/figures ; rm -rf seahorse-window.png )
( cd usr/share/gnome/help/seahorse/oc/figures ; ln -sf ../../C/figures/seahorse-window.png seahorse-window.png )

if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"    usr/bin/gconftool-2 --makefile-install-rule    etc/gconf/schemas/*.schemas >/dev/null 2>&1
fi
# update rarian
if [ -x usr/bin/rarian-sk-update ]; then
  usr/bin/rarian-sk-update 1> /dev/null 2> /dev/null
fi

# update desktop entries
if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

# update icon cache
if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
	rm -f usr/share/icons/hicolor/icon-theme.cache
fi
usr/bin/gtk-update-icon-cache -f -q usr/share/icons/hicolor
